@@ -11,50 +11,64 @@ class CommonHarnessLib:
     def __init__(self, enable_s3: bool = True, ignore_json_args: bool = False):
         # Get JSON parameters from harness
         if not ignore_json_args:
-            try:
-                loads(argv[1])
-            except IndexError:
-                raise ValueError("Harness JSON args not given.")
-            except ValueError:
-                raise ValueError("Invalid JSON harness args.")
-            except Exception as e:
-                raise ValueError(type(e).__name__ + ": " + e)
-
+            self.get_json_args()
         # Deal with s3 initialization
         if enable_s3:
-            # Only import s3 libraries if s3 is enabled (unholy but efficient)
-            import boto3
-            from botocore.client import Config
-            # Validate environ vars exist
-            try:
-                self.validate_dict(environ, {
-                        "AWS_WORDLIST_BUCKET": str,
-                        "S3_URL": typing.Optional[str],
-                        "AWS_ACCESS_KEY_ID": str,
-                        "AWS_SECRET_ACCESS_KEY": str,
-                        "AWS_REGION": str
-                    })
-            except ValueError as e:
-                error = e.args[0].replace("parameter", "environment variable")
-                raise ValueError(error) from None
-            # Create S3 resources from environ
-            self.AWS_WORDLIST_BUCKET = environ.get("AWS_WORDLIST_BUCKET")
-            self.s3 = boto3.resource(
-                "s3",
-                endpoint_url=environ.get("S3_URL"),
-                aws_access_key_id=environ.get("AWS_ACCESS_KEY_ID"),
-                aws_secret_access_key=environ.get("AWS_SECRET_ACCESS_KEY"),
-                config=Config(signature_version="s3v4"),
-                region_name=environ.get("AWS_REGION")
-            )
-            # Validate bucket details valid
-            try:
-                self.s3.meta.client.head_bucket(
-                    Bucket=self.AWS_WORDLIST_BUCKET
-                )
-            except Exception as e:
-                self.handle_s3_exception(e)
+            self.init_s3()
 
+    """
+        Parse JSON from argv[1], which is standard harness input format
+    """
+    def get_json_args(self):
+        try:
+            self.json_args = loads(argv[1])
+        except IndexError:
+            raise ValueError("Harness JSON args not given.")
+        except ValueError:
+            raise ValueError("Invalid JSON harness args.")
+        except Exception as e:
+            raise ValueError(type(e).__name__ + ": " + e)
+
+    """
+        Initiliase and verify s3 details
+    """
+    def init_s3(self):
+        # Only import s3 libraries if s3 is enabled (unholy but efficient)
+        import boto3
+        from botocore.client import Config
+        # Validate environ vars exist
+        try:
+            self.validate_dict(environ, {
+                    "AWS_WORDLIST_BUCKET": str,
+                    "S3_URL": typing.Optional[str],
+                    "AWS_ACCESS_KEY_ID": str,
+                    "AWS_SECRET_ACCESS_KEY": str,
+                    "AWS_REGION": str
+                })
+        except ValueError as e:
+            error = e.args[0].replace("parameter", "environment variable")
+            raise ValueError(error) from None
+        # Create S3 resources from environ
+        self.AWS_WORDLIST_BUCKET = environ.get("AWS_WORDLIST_BUCKET")
+        self.s3 = boto3.resource(
+            "s3",
+            endpoint_url=environ.get("S3_URL"),
+            aws_access_key_id=environ.get("AWS_ACCESS_KEY_ID"),
+            aws_secret_access_key=environ.get("AWS_SECRET_ACCESS_KEY"),
+            config=Config(signature_version="s3v4"),
+            region_name=environ.get("AWS_REGION")
+        )
+        # Validate bucket details valid
+        try:
+            self.s3.meta.client.head_bucket(
+                Bucket=self.AWS_WORDLIST_BUCKET
+            )
+        except Exception as e:
+            self.handle_s3_exception(e)
+
+    """
+        Handle common s3 exceptions
+    """
     def handle_s3_exception(self, error: Exception):
         error_type = type(error)
         if error_type == self.s3.meta.client.exceptions.ClientError:
@@ -66,7 +80,9 @@ class CommonHarnessLib:
         else:
             raise error from None
 
-    # Get content of a bucket object as a string
+    """
+        Get content of a bucket object as a string.
+    """
     def get_object_content(self, bucket_name: str, object_key: str):
         s3_object = self.s3.Object(bucket_name, object_key)
         try:
@@ -76,7 +92,9 @@ class CommonHarnessLib:
         except Exception as e:
             self.handle_s3_exception(e)
 
-    # Download a list of wordlist keys, and join to create one wordlist
+    """
+        Download a list of wordlist keys, and join to create one wordlist.
+    """
     def download_wordlists(self, wordlist_keys: str):
         # Create file
         with open("wordlist.txt", "w") as f:
@@ -99,6 +117,14 @@ class CommonHarnessLib:
         # Return wordlist filepath
         return "wordlist.txt"
 
+    """
+        Validate dictionary entries by type
+        i.e.
+            validate_dict({"wordlists": [], "company": "a"}, {
+                "wordlists": List[str],
+                "company": str
+            })
+    """
     # Validate dictionary entries match required type
     def validate_dict(self, args: dict, required: dict):
         # Iterate through required entries
@@ -147,7 +173,9 @@ class CommonHarnessLib:
                         f"Provided parameter {required_param} should be type {required_type}."  # NOQA: E501
                     )
 
-    # Run simple command with subprocess Popen
+    """
+        Run simple command with subprocess Popen
+    """
     def run_command(
             self,
             command,  # Command to run in array
